[longomatch] Change background color of the analysis window



commit 981f5e2194e158a871f7da2fea783a11fda1f52c
Author: Andoni Morales Alastruey <ylatuya gmail com>
Date:   Tue Aug 26 18:13:25 2014 +0200

    Change background color of the analysis window

 LongoMatch.GUI.Multimedia/Gui/VideoWindow.cs       |    8 +-
 .../gtk-gui/LongoMatch.Gui.PlayerBin.cs            |    1 -
 .../gtk-gui/LongoMatch.Gui.VideoWindow.cs          |    8 +-
 LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic       |    3 +-
 LongoMatch.GUI/Gui/Component/AnalysisComponent.cs  |   10 +-
 .../LongoMatch.Gui.Component.CodingWidget.cs       |   33 +-
 ...ongoMatch.Gui.Component.PlaysSelectionWidget.cs |  101 +++---
 .../gtk-gui/LongoMatch.Gui.MainWindow.cs           |    1 -
 LongoMatch.GUI/gtk-gui/gui.stetic                  |  389 +++++++++-----------
 data/theme/gtk-2.0/gtkrc                           |    1 +
 10 files changed, 263 insertions(+), 292 deletions(-)
---
diff --git a/LongoMatch.GUI.Multimedia/Gui/VideoWindow.cs b/LongoMatch.GUI.Multimedia/Gui/VideoWindow.cs
index a2fe316..1edb135 100644
--- a/LongoMatch.GUI.Multimedia/Gui/VideoWindow.cs
+++ b/LongoMatch.GUI.Multimedia/Gui/VideoWindow.cs
@@ -39,12 +39,12 @@ namespace LongoMatch.Gui
                        Window.DoubleBuffered = false;
                        Window.Realized += HandleRealized;
                        Window.ExposeEvent += HandleExposeEvent;
-                       eventbox.ButtonPressEvent += HandleButtonPressEvent;
-                       eventbox.ScrollEvent += HandleScrollEvent;
-                       eventbox.BorderWidth = 0;
+                       videoeventbox.ButtonPressEvent += HandleButtonPressEvent;
+                       videoeventbox.ScrollEvent += HandleScrollEvent;
+                       videoeventbox.BorderWidth = 0;
 
                        frame.Add (Window);
-                       eventbox.Add (frame);
+                       videoeventbox.Add (frame);
                        ShowAll ();
                }
 
diff --git a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerBin.cs 
b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerBin.cs
index 9e7b08b..405c498 100644
--- a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerBin.cs
+++ b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerBin.cs
@@ -56,7 +56,6 @@ namespace LongoMatch.Gui
                        // Container child videobox.Gtk.Box+BoxChild
                        this.hbox2 = new global::Gtk.HBox ();
                        this.hbox2.Name = "hbox2";
-                       this.hbox2.Spacing = 6;
                        // Container child hbox2.Gtk.Box+BoxChild
                        this.videowindow = new global::LongoMatch.Gui.VideoWindow ();
                        this.videowindow.Events = ((global::Gdk.EventMask)(256));
diff --git a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.VideoWindow.cs 
b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.VideoWindow.cs
index 7d80bf1..0cb0523 100644
--- a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.VideoWindow.cs
+++ b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.VideoWindow.cs
@@ -4,7 +4,7 @@ namespace LongoMatch.Gui
 {
        public partial class VideoWindow
        {
-               private global::Gtk.EventBox eventbox;
+               private global::Gtk.EventBox videoeventbox;
 
                protected virtual void Build ()
                {
@@ -13,9 +13,9 @@ namespace LongoMatch.Gui
                        global::Stetic.BinContainer.Attach (this);
                        this.Name = "LongoMatch.Gui.VideoWindow";
                        // Container child LongoMatch.Gui.VideoWindow.Gtk.Container+ContainerChild
-                       this.eventbox = new global::Gtk.EventBox ();
-                       this.eventbox.Name = "eventbox";
-                       this.Add (this.eventbox);
+                       this.videoeventbox = new global::Gtk.EventBox ();
+                       this.videoeventbox.Name = "videoeventbox";
+                       this.Add (this.videoeventbox);
                        if ((this.Child != null)) {
                                this.Child.ShowAll ();
                        }
diff --git a/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic b/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
index ee9ccbd..2283d20 100644
--- a/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
+++ b/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
@@ -95,7 +95,6 @@
                     <child>
                       <widget class="Gtk.HBox" id="hbox2">
                         <property name="MemberName" />
-                        <property name="Spacing">6</property>
                         <child>
                           <widget class="LongoMatch.Gui.VideoWindow" id="videowindow">
                             <property name="MemberName" />
@@ -626,7 +625,7 @@
     <property name="MemberName" />
     <property name="Visible">False</property>
     <child>
-      <widget class="Gtk.EventBox" id="eventbox">
+      <widget class="Gtk.EventBox" id="videoeventbox">
         <property name="MemberName" />
         <child>
           <placeholder />
diff --git a/LongoMatch.GUI/Gui/Component/AnalysisComponent.cs 
b/LongoMatch.GUI/Gui/Component/AnalysisComponent.cs
index bce8696..66abe49 100644
--- a/LongoMatch.GUI/Gui/Component/AnalysisComponent.cs
+++ b/LongoMatch.GUI/Gui/Component/AnalysisComponent.cs
@@ -30,6 +30,7 @@ namespace LongoMatch.Gui.Component
                ProjectType projectType;
                bool detachedPlayer;
                Gtk.Window playerWindow;
+               EventBox backgroundBox;
                PlaysSelectionWidget playsSelection;
                PlayerCapturerBin playercapturer;
                CodingWidget codingwidget;
@@ -140,6 +141,8 @@ namespace LongoMatch.Gui.Component
                }
                
                void CreateCommonUI () {
+                       backgroundBox = new EventBox ();
+                       backgroundBox.Name = "lightbackgroundeventbox";
                        videowidgetsbox = new HBox ();
                        playsSelection = new PlaysSelectionWidget ();
                        codingwidget = new CodingWidget();
@@ -155,6 +158,7 @@ namespace LongoMatch.Gui.Component
                                playercapturer.PeriodsNames = openedProject.Categories.GamePeriods;
                                playercapturer.PeriodsTimers = openedProject.Periods;
                        }
+                       backgroundBox.Show ();
                        playsSelection.Show ();
                        codingwidget.Show ();
                        playercapturer.Show ();
@@ -182,7 +186,8 @@ namespace LongoMatch.Gui.Component
                        videowidgetsbox.Add (playercapturer);
                        vbox.PackStart (videowidgetsbox, false, true, 0);
                        vbox.PackEnd (codingwidget, true, true, 0);
-                       Add (centralpane);
+                       backgroundBox.Add (centralpane);
+                       Add (backgroundBox);
                }
 
                void CreatePreviewUI () {
@@ -206,7 +211,8 @@ namespace LongoMatch.Gui.Component
                        uppane.Pack2 (rightpane, true, true);
                        videowidgetsbox.Add (playercapturer);
                        rightpane.Pack1 (videowidgetsbox, true, true);
-                       Add (centralpane);
+                       backgroundBox.Add (centralpane);
+                       Add (backgroundBox);
                }
                
                void ClearWidgets() {
diff --git a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.CodingWidget.cs 
b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.CodingWidget.cs
index 439d885..e358d7f 100644
--- a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.CodingWidget.cs
+++ b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.CodingWidget.cs
@@ -5,12 +5,11 @@ namespace LongoMatch.Gui.Component
        public partial class CodingWidget
        {
                private global::Gtk.UIManager UIManager;
-               private global::Gtk.RadioAction positionMode;
                private global::Gtk.RadioAction timelineMode;
                private global::Gtk.RadioAction autoTaggingMode;
                private global::Gtk.Action zoomFitAction;
                private global::Gtk.RadioAction convertAction;
-               private global::Gtk.EventBox lightbackgroundeventbox;
+               private global::Gtk.RadioAction positionMode;
                private global::Gtk.Notebook notebook;
                private global::Gtk.HPaned dashboardhpaned;
                private global::Gtk.DrawingArea teamsdrawingarea;
@@ -28,29 +27,26 @@ namespace LongoMatch.Gui.Component
                        // Widget LongoMatch.Gui.Component.CodingWidget
                        Stetic.BinContainer w1 = global::Stetic.BinContainer.Attach (this);
                        this.UIManager = new global::Gtk.UIManager ();
-                       global::Gtk.ActionGroup w2 = new global::Gtk.ActionGroup ("Timeline");
-                       this.positionMode = new global::Gtk.RadioAction ("positionMode", null, null, 
"gtk-justify-fill", 0);
-                       this.positionMode.Group = new global::GLib.SList (global::System.IntPtr.Zero);
-                       w2.Add (this.positionMode, null);
-                       this.UIManager.InsertActionGroup (w2, 0);
-                       global::Gtk.ActionGroup w3 = new global::Gtk.ActionGroup ("Default");
+                       global::Gtk.ActionGroup w2 = new global::Gtk.ActionGroup ("Default");
                        this.timelineMode = new global::Gtk.RadioAction ("timelineMode", null, 
global::Mono.Unix.Catalog.GetString ("Timeline view"), "gtk-justify-fill", 0);
-                       this.timelineMode.Group = this.positionMode.Group;
-                       w3.Add (this.timelineMode, null);
+                       this.timelineMode.Group = new global::GLib.SList (global::System.IntPtr.Zero);
+                       w2.Add (this.timelineMode, null);
                        this.autoTaggingMode = new global::Gtk.RadioAction ("autoTaggingMode", null, 
global::Mono.Unix.Catalog.GetString ("Automatic tagging view"), "gtk-select-color", 0);
-                       this.autoTaggingMode.Group = this.positionMode.Group;
-                       w3.Add (this.autoTaggingMode, null);
+                       this.autoTaggingMode.Group = this.timelineMode.Group;
+                       w2.Add (this.autoTaggingMode, null);
                        this.zoomFitAction = new global::Gtk.Action ("zoomFitAction", null, null, 
"gtk-zoom-fit");
-                       w3.Add (this.zoomFitAction, null);
+                       w2.Add (this.zoomFitAction, null);
                        this.convertAction = new global::Gtk.RadioAction ("convertAction", null, null, 
"gtk-convert", 0);
                        this.convertAction.Group = this.autoTaggingMode.Group;
-                       w3.Add (this.convertAction, null);
+                       w2.Add (this.convertAction, null);
+                       this.UIManager.InsertActionGroup (w2, 0);
+                       global::Gtk.ActionGroup w3 = new global::Gtk.ActionGroup ("Timeline");
+                       this.positionMode = new global::Gtk.RadioAction ("positionMode", null, null, 
"gtk-justify-fill", 0);
+                       this.positionMode.Group = this.autoTaggingMode.Group;
+                       w3.Add (this.positionMode, null);
                        this.UIManager.InsertActionGroup (w3, 1);
                        this.Name = "LongoMatch.Gui.Component.CodingWidget";
                        // Container child LongoMatch.Gui.Component.CodingWidget.Gtk.Container+ContainerChild
-                       this.lightbackgroundeventbox = new global::Gtk.EventBox ();
-                       this.lightbackgroundeventbox.Name = "lightbackgroundeventbox";
-                       // Container child lightbackgroundeventbox.Gtk.Container+ContainerChild
                        this.notebook = new global::Gtk.Notebook ();
                        this.notebook.CanFocus = true;
                        this.notebook.Name = "notebook";
@@ -114,8 +110,7 @@ namespace LongoMatch.Gui.Component
                        this.label5.LabelProp = global::Mono.Unix.Catalog.GetString ("page3");
                        this.notebook.SetTabLabel (this.playspositionviewer1, this.label5);
                        this.label5.ShowAll ();
-                       this.lightbackgroundeventbox.Add (this.notebook);
-                       this.Add (this.lightbackgroundeventbox);
+                       this.Add (this.notebook);
                        if ((this.Child != null)) {
                                this.Child.ShowAll ();
                        }
diff --git a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.MainWindow.cs 
b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.MainWindow.cs
index 9ab970a..d0ba227 100644
--- a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.MainWindow.cs
+++ b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.MainWindow.cs
@@ -147,7 +147,6 @@ namespace LongoMatch.Gui
                        // Container child LongoMatch.Gui.MainWindow.Gtk.Container+ContainerChild
                        this.vbox1 = new global::Gtk.VBox ();
                        this.vbox1.Name = "vbox1";
-                       this.vbox1.Spacing = 6;
                        // Container child vbox1.Gtk.Box+BoxChild
                        this.menubox = new global::Gtk.VBox ();
                        this.menubox.Name = "menubox";
diff --git a/LongoMatch.GUI/gtk-gui/gui.stetic b/LongoMatch.GUI/gtk-gui/gui.stetic
index a043bbf..fb21ce7 100644
--- a/LongoMatch.GUI/gtk-gui/gui.stetic
+++ b/LongoMatch.GUI/gtk-gui/gui.stetic
@@ -775,7 +775,6 @@
     <child>
       <widget class="Gtk.VBox" id="vbox1">
         <property name="MemberName" />
-        <property name="Spacing">6</property>
         <child>
           <widget class="Gtk.VBox" id="menubox">
             <property name="MemberName" />
@@ -4069,86 +4068,35 @@ You can continue with the current capture, cancel it or save your project.
     <property name="MemberName" />
     <property name="Visible">False</property>
     <child>
-      <widget class="Gtk.EventBox" id="lightbackgroundeventbox">
+      <widget class="Gtk.Notebook" id="notebook">
         <property name="MemberName" />
+        <property name="CanFocus">True</property>
+        <property name="CurrentPage">2</property>
+        <property name="TabPos">Left</property>
         <child>
-          <widget class="Gtk.Notebook" id="notebook2">
+          <widget class="Gtk.Notebook" id="playsnotebook">
             <property name="MemberName" />
             <property name="CanFocus">True</property>
-            <property name="CurrentPage">0</property>
-            <property name="TabPos">Left</property>
+            <property name="CurrentPage">2</property>
+            <property name="TabPos">Bottom</property>
             <child>
-              <widget class="Gtk.Notebook" id="notebook1">
+              <widget class="LongoMatch.Gui.Component.PlaysListTreeWidget" id="playsList">
                 <property name="MemberName" />
-                <property name="CanFocus">True</property>
-                <property name="CurrentPage">2</property>
-                <property name="TabPos">Bottom</property>
-                <child>
-                  <widget class="LongoMatch.Gui.Component.PlaysListTreeWidget" id="playsList">
-                    <property name="MemberName" />
-                    <property name="Events">ButtonPressMask</property>
-                  </widget>
-                </child>
-                <child>
-                  <widget class="Gtk.Label" id="playsList1">
-                    <property name="MemberName" />
-                    <property name="LabelProp" translatable="yes">Plays</property>
-                  </widget>
-                  <packing>
-                    <property name="type">tab</property>
-                  </packing>
-                </child>
-                <child>
-                  <widget class="LongoMatch.Gui.Component.PlayersListTreeWidget" id="localPlayersList">
-                    <property name="MemberName" />
-                    <property name="Events">ButtonPressMask</property>
-                  </widget>
-                  <packing>
-                    <property name="Position">1</property>
-                  </packing>
-                </child>
-                <child>
-                  <widget class="Gtk.Label" id="localPlaysList">
-                    <property name="MemberName" />
-                  </widget>
-                  <packing>
-                    <property name="type">tab</property>
-                  </packing>
-                </child>
-                <child>
-                  <widget class="LongoMatch.Gui.Component.PlayersListTreeWidget" id="visitorPlayersList">
-                    <property name="MemberName" />
-                    <property name="Events">ButtonPressMask</property>
-                  </widget>
-                  <packing>
-                    <property name="Position">2</property>
-                  </packing>
-                </child>
-                <child>
-                  <widget class="Gtk.Label" id="visitorPlaysList">
-                    <property name="MemberName" />
-                  </widget>
-                  <packing>
-                    <property name="type">tab</property>
-                  </packing>
-                </child>
+                <property name="Events">ButtonPressMask</property>
               </widget>
             </child>
             <child>
-              <widget class="Gtk.Label" id="label1">
+              <widget class="Gtk.Label" id="playsList1">
                 <property name="MemberName" />
-                <property name="LabelProp" translatable="yes">  Plays Selection   </property>
-                <property name="Justify">Center</property>
-                <property name="Angle">90</property>
+                <property name="LabelProp" translatable="yes">Plays</property>
               </widget>
               <packing>
                 <property name="type">tab</property>
               </packing>
             </child>
             <child>
-              <widget class="LongoMatch.Gui.Component.PlayListWidget" id="playlistwidget">
+              <widget class="LongoMatch.Gui.Component.PlayersListTreeWidget" id="localPlayersList">
                 <property name="MemberName" />
-                <property name="WidthRequest">100</property>
                 <property name="Events">ButtonPressMask</property>
               </widget>
               <packing>
@@ -4156,87 +4104,133 @@ You can continue with the current capture, cancel it or save your project.
               </packing>
             </child>
             <child>
-              <widget class="Gtk.Label" id="label3">
+              <widget class="Gtk.Label" id="localPlaysList">
                 <property name="MemberName" />
-                <property name="LabelProp" translatable="yes">Playlists</property>
-                <property name="Angle">90</property>
               </widget>
               <packing>
                 <property name="type">tab</property>
               </packing>
             </child>
             <child>
-              <widget class="Gtk.VBox" id="vbox3">
+              <widget class="LongoMatch.Gui.Component.PlayersListTreeWidget" id="visitorPlayersList">
                 <property name="MemberName" />
-                <property name="Spacing">6</property>
-                <child>
-                  <widget class="Gtk.Notebook" id="filtersnotebook">
-                    <property name="MemberName" />
-                    <property name="CanFocus">True</property>
-                    <property name="CurrentPage">0</property>
-                    <property name="TabPos">Bottom</property>
-                    <child>
-                      <placeholder />
-                    </child>
-                    <child>
-                      <placeholder />
-                    </child>
-                  </widget>
-                  <packing>
-                    <property name="Position">0</property>
-                    <property name="AutoSize">True</property>
-                  </packing>
-                </child>
+                <property name="Events">ButtonPressMask</property>
+              </widget>
+              <packing>
+                <property name="Position">2</property>
+              </packing>
+            </child>
+            <child>
+              <widget class="Gtk.Label" id="visitorPlaysList">
+                <property name="MemberName" />
+              </widget>
+              <packing>
+                <property name="type">tab</property>
+              </packing>
+            </child>
+          </widget>
+        </child>
+        <child>
+          <widget class="Gtk.Label" id="label1">
+            <property name="MemberName" />
+            <property name="LabelProp" translatable="yes">  Plays Selection   </property>
+            <property name="Justify">Center</property>
+            <property name="Angle">90</property>
+          </widget>
+          <packing>
+            <property name="type">tab</property>
+          </packing>
+        </child>
+        <child>
+          <widget class="LongoMatch.Gui.Component.PlayListWidget" id="playlistwidget">
+            <property name="MemberName" />
+            <property name="WidthRequest">100</property>
+            <property name="Events">ButtonPressMask</property>
+          </widget>
+          <packing>
+            <property name="Position">1</property>
+          </packing>
+        </child>
+        <child>
+          <widget class="Gtk.Label" id="label3">
+            <property name="MemberName" />
+            <property name="LabelProp" translatable="yes">Playlists</property>
+            <property name="Angle">90</property>
+          </widget>
+          <packing>
+            <property name="type">tab</property>
+          </packing>
+        </child>
+        <child>
+          <widget class="Gtk.VBox" id="filtersvbox">
+            <property name="MemberName" />
+            <property name="Spacing">6</property>
+            <child>
+              <widget class="Gtk.Notebook" id="filtersnotebook">
+                <property name="MemberName" />
+                <property name="CanFocus">True</property>
+                <property name="CurrentPage">0</property>
+                <property name="TabPos">Bottom</property>
                 <child>
-                  <widget class="Gtk.ToggleButton" id="catfiltersbutton">
-                    <property name="MemberName" />
-                    <property name="CanFocus">True</property>
-                    <property name="Type">TextAndIcon</property>
-                    <property name="Icon">stock:gtk-find Menu</property>
-                    <property name="Label" translatable="yes">Activate categories filters</property>
-                    <property name="UseUnderline">True</property>
-                    <signal name="Clicked" handler="OnCategoriesFiltersbuttonClicked" />
-                  </widget>
-                  <packing>
-                    <property name="Position">1</property>
-                    <property name="AutoSize">True</property>
-                    <property name="Expand">False</property>
-                    <property name="Fill">False</property>
-                  </packing>
+                  <placeholder />
                 </child>
                 <child>
-                  <widget class="Gtk.ToggleButton" id="playersfiltersbutton">
-                    <property name="MemberName" />
-                    <property name="CanFocus">True</property>
-                    <property name="Type">TextAndIcon</property>
-                    <property name="Icon">stock:gtk-find Menu</property>
-                    <property name="Label" translatable="yes">Activate players filters</property>
-                    <property name="UseUnderline">True</property>
-                    <signal name="Clicked" handler="OnPlayersFiltersbuttonClicked" />
-                  </widget>
-                  <packing>
-                    <property name="Position">2</property>
-                    <property name="AutoSize">True</property>
-                    <property name="Expand">False</property>
-                    <property name="Fill">False</property>
-                  </packing>
+                  <placeholder />
                 </child>
               </widget>
               <packing>
-                <property name="Position">2</property>
+                <property name="Position">0</property>
+                <property name="AutoSize">True</property>
               </packing>
             </child>
             <child>
-              <widget class="Gtk.Label" id="label2">
+              <widget class="Gtk.ToggleButton" id="catfiltersbutton">
                 <property name="MemberName" />
-                <property name="LabelProp" translatable="yes">  Filters  </property>
-                <property name="Angle">90</property>
+                <property name="CanFocus">True</property>
+                <property name="Type">TextAndIcon</property>
+                <property name="Icon">stock:gtk-find Menu</property>
+                <property name="Label" translatable="yes">Activate categories filters</property>
+                <property name="UseUnderline">True</property>
+                <signal name="Clicked" handler="OnCategoriesFiltersbuttonClicked" />
               </widget>
               <packing>
-                <property name="type">tab</property>
+                <property name="Position">1</property>
+                <property name="AutoSize">True</property>
+                <property name="Expand">False</property>
+                <property name="Fill">False</property>
+              </packing>
+            </child>
+            <child>
+              <widget class="Gtk.ToggleButton" id="playersfiltersbutton">
+                <property name="MemberName" />
+                <property name="CanFocus">True</property>
+                <property name="Type">TextAndIcon</property>
+                <property name="Icon">stock:gtk-find Menu</property>
+                <property name="Label" translatable="yes">Activate players filters</property>
+                <property name="UseUnderline">True</property>
+                <signal name="Clicked" handler="OnPlayersFiltersbuttonClicked" />
+              </widget>
+              <packing>
+                <property name="Position">2</property>
+                <property name="AutoSize">True</property>
+                <property name="Expand">False</property>
+                <property name="Fill">False</property>
               </packing>
             </child>
           </widget>
+          <packing>
+            <property name="Position">2</property>
+          </packing>
+        </child>
+        <child>
+          <widget class="Gtk.Label" id="label2">
+            <property name="MemberName" />
+            <property name="LabelProp" translatable="yes">  Filters  </property>
+            <property name="Angle">90</property>
+          </widget>
+          <packing>
+            <property name="type">tab</property>
+          </packing>
         </child>
       </widget>
     </child>
@@ -7920,7 +7914,6 @@ You can continue with the current capture, cancel it or save your project.
                 <child>
                   <widget class="Gtk.Frame" id="playerframe">
                     <property name="MemberName" />
-                    <property name="Sensitive">False</property>
                     <property name="ShadowType">In</property>
                     <child>
                       <widget class="Gtk.Alignment" id="playerpropertyalignment">
@@ -9874,108 +9867,92 @@ You can continue with the current capture, cancel it or save your project.
         <property name="Group">codingmode</property>
       </action>
     </action-group>
-    <action-group name="Timeline">
-      <action id="positionMode">
-        <property name="Type">Radio</property>
-        <property name="Label" translatable="yes" />
-        <property name="StockId">gtk-justify-fill</property>
-        <property name="DrawAsRadio">False</property>
-        <property name="Active">False</property>
-        <property name="Value">0</property>
-        <property name="Group">codingmode</property>
-      </action>
-    </action-group>
     <property name="MemberName" />
     <property name="Visible">False</property>
     <child>
-      <widget class="Gtk.EventBox" id="lightbackgroundeventbox">
+      <widget class="Gtk.Notebook" id="notebook">
         <property name="MemberName" />
+        <property name="CanFocus">True</property>
+        <property name="CurrentPage">0</property>
+        <property name="TabPos">Left</property>
+        <property name="ShowBorder">False</property>
         <child>
-          <widget class="Gtk.Notebook" id="notebook">
+          <widget class="Gtk.HPaned" id="dashboardhpaned">
             <property name="MemberName" />
             <property name="CanFocus">True</property>
-            <property name="CurrentPage">0</property>
-            <property name="TabPos">Left</property>
-            <property name="ShowBorder">False</property>
-            <child>
-              <widget class="Gtk.HPaned" id="dashboardhpaned">
-                <property name="MemberName" />
-                <property name="CanFocus">True</property>
-                <property name="Position">276</property>
-                <child>
-                  <widget class="Gtk.DrawingArea" id="teamsdrawingarea">
-                    <property name="MemberName" />
-                  </widget>
-                  <packing>
-                    <property name="Resize">False</property>
-                  </packing>
-                </child>
-                <child>
-                  <widget class="Gtk.HBox" id="hbox5">
-                    <property name="MemberName" />
-                    <property name="Spacing">6</property>
-                    <child>
-                      <widget class="LongoMatch.Gui.Component.DashboardWidget" id="buttonswidget">
-                        <property name="MemberName" />
-                        <property name="Events">ButtonPressMask</property>
-                        <property name="Edited">False</property>
-                      </widget>
-                      <packing>
-                        <property name="Position">0</property>
-                        <property name="AutoSize">True</property>
-                      </packing>
-                    </child>
-                  </widget>
-                </child>
-              </widget>
-            </child>
+            <property name="Position">276</property>
             <child>
-              <widget class="Gtk.Label" id="label2">
+              <widget class="Gtk.DrawingArea" id="teamsdrawingarea">
                 <property name="MemberName" />
-                <property name="LabelProp" translatable="yes">page1</property>
               </widget>
               <packing>
-                <property name="type">tab</property>
-              </packing>
-            </child>
-            <child>
-              <widget class="LongoMatch.Gui.Component.Timeline" id="timeline">
-                <property name="MemberName" />
-                <property name="Events">ButtonPressMask</property>
-              </widget>
-              <packing>
-                <property name="Position">1</property>
-              </packing>
-            </child>
-            <child>
-              <widget class="Gtk.Label" id="label3">
-                <property name="MemberName" />
-                <property name="LabelProp" translatable="yes">page2</property>
-              </widget>
-              <packing>
-                <property name="type">tab</property>
-              </packing>
-            </child>
-            <child>
-              <widget class="LongoMatch.Gui.Component.PlaysPositionViewer" id="playspositionviewer1">
-                <property name="MemberName" />
-                <property name="Events">ButtonPressMask</property>
-              </widget>
-              <packing>
-                <property name="Position">2</property>
+                <property name="Resize">False</property>
               </packing>
             </child>
             <child>
-              <widget class="Gtk.Label" id="label5">
+              <widget class="Gtk.HBox" id="hbox5">
                 <property name="MemberName" />
-                <property name="LabelProp" translatable="yes">page3</property>
+                <property name="Spacing">6</property>
+                <child>
+                  <widget class="LongoMatch.Gui.Component.DashboardWidget" id="buttonswidget">
+                    <property name="MemberName" />
+                    <property name="Events">ButtonPressMask</property>
+                    <property name="Edited">False</property>
+                  </widget>
+                  <packing>
+                    <property name="Position">0</property>
+                    <property name="AutoSize">True</property>
+                  </packing>
+                </child>
               </widget>
-              <packing>
-                <property name="type">tab</property>
-              </packing>
             </child>
           </widget>
         </child>
+        <child>
+          <widget class="Gtk.Label" id="label2">
+            <property name="MemberName" />
+            <property name="LabelProp" translatable="yes">page1</property>
+          </widget>
+          <packing>
+            <property name="type">tab</property>
+          </packing>
+        </child>
+        <child>
+          <widget class="LongoMatch.Gui.Component.Timeline" id="timeline">
+            <property name="MemberName" />
+            <property name="Events">ButtonPressMask</property>
+          </widget>
+          <packing>
+            <property name="Position">1</property>
+          </packing>
+        </child>
+        <child>
+          <widget class="Gtk.Label" id="label3">
+            <property name="MemberName" />
+            <property name="LabelProp" translatable="yes">page2</property>
+          </widget>
+          <packing>
+            <property name="type">tab</property>
+          </packing>
+        </child>
+        <child>
+          <widget class="LongoMatch.Gui.Component.PlaysPositionViewer" id="playspositionviewer1">
+            <property name="MemberName" />
+            <property name="Events">ButtonPressMask</property>
+          </widget>
+          <packing>
+            <property name="Position">2</property>
+          </packing>
+        </child>
+        <child>
+          <widget class="Gtk.Label" id="label5">
+            <property name="MemberName" />
+            <property name="LabelProp" translatable="yes">page3</property>
+          </widget>
+          <packing>
+            <property name="type">tab</property>
+          </packing>
+        </child>
       </widget>
     </child>
   </widget>
diff --git a/data/theme/gtk-2.0/gtkrc b/data/theme/gtk-2.0/gtkrc
index 0962cb7..8845a2e 100644
--- a/data/theme/gtk-2.0/gtkrc
+++ b/data/theme/gtk-2.0/gtkrc
@@ -298,3 +298,4 @@ widget "*datepicker*button*" style "longomatch-filechooser-button"
 widget "*datepicker*entry*" style "longomatch-filechooser-entry"
 widget "*mediafilechooser*button*" style "longomatch-filechooser-button"
 widget "*lightbackgroundeventbox*" style "longomatch-light-background"
+widget "*videoeventbox*" style "longomatch-default"



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.PlaysSelectionWidget.cs 
b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.PlaysSelectionWidget.cs
index 0e1b81d..a77dd95 100644
--- a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.PlaysSelectionWidget.cs
+++ b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.PlaysSelectionWidget.cs
@@ -4,9 +4,8 @@ namespace LongoMatch.Gui.Component
 {
        public partial class PlaysSelectionWidget
        {
-               private global::Gtk.EventBox lightbackgroundeventbox;
-               private global::Gtk.Notebook notebook2;
-               private global::Gtk.Notebook notebook1;
+               private global::Gtk.Notebook notebook;
+               private global::Gtk.Notebook playsnotebook;
                private global::LongoMatch.Gui.Component.PlaysListTreeWidget playsList;
                private global::Gtk.Label playsList1;
                private global::LongoMatch.Gui.Component.PlayersListTreeWidget localPlayersList;
@@ -16,7 +15,7 @@ namespace LongoMatch.Gui.Component
                private global::Gtk.Label label1;
                private global::LongoMatch.Gui.Component.PlayListWidget playlistwidget;
                private global::Gtk.Label label3;
-               private global::Gtk.VBox vbox3;
+               private global::Gtk.VBox filtersvbox;
                private global::Gtk.Notebook filtersnotebook;
                private global::Gtk.ToggleButton catfiltersbutton;
                private global::Gtk.ToggleButton playersfiltersbutton;
@@ -29,93 +28,90 @@ namespace LongoMatch.Gui.Component
                        global::Stetic.BinContainer.Attach (this);
                        this.Name = "LongoMatch.Gui.Component.PlaysSelectionWidget";
                        // Container child 
LongoMatch.Gui.Component.PlaysSelectionWidget.Gtk.Container+ContainerChild
-                       this.lightbackgroundeventbox = new global::Gtk.EventBox ();
-                       this.lightbackgroundeventbox.Name = "lightbackgroundeventbox";
-                       // Container child lightbackgroundeventbox.Gtk.Container+ContainerChild
-                       this.notebook2 = new global::Gtk.Notebook ();
-                       this.notebook2.CanFocus = true;
-                       this.notebook2.Name = "notebook2";
-                       this.notebook2.CurrentPage = 0;
-                       this.notebook2.TabPos = ((global::Gtk.PositionType)(0));
-                       // Container child notebook2.Gtk.Notebook+NotebookChild
-                       this.notebook1 = new global::Gtk.Notebook ();
-                       this.notebook1.CanFocus = true;
-                       this.notebook1.Name = "notebook1";
-                       this.notebook1.CurrentPage = 2;
-                       this.notebook1.TabPos = ((global::Gtk.PositionType)(3));
-                       // Container child notebook1.Gtk.Notebook+NotebookChild
+                       this.notebook = new global::Gtk.Notebook ();
+                       this.notebook.CanFocus = true;
+                       this.notebook.Name = "notebook";
+                       this.notebook.CurrentPage = 2;
+                       this.notebook.TabPos = ((global::Gtk.PositionType)(0));
+                       // Container child notebook.Gtk.Notebook+NotebookChild
+                       this.playsnotebook = new global::Gtk.Notebook ();
+                       this.playsnotebook.CanFocus = true;
+                       this.playsnotebook.Name = "playsnotebook";
+                       this.playsnotebook.CurrentPage = 2;
+                       this.playsnotebook.TabPos = ((global::Gtk.PositionType)(3));
+                       // Container child playsnotebook.Gtk.Notebook+NotebookChild
                        this.playsList = new global::LongoMatch.Gui.Component.PlaysListTreeWidget ();
                        this.playsList.Events = ((global::Gdk.EventMask)(256));
                        this.playsList.Name = "playsList";
-                       this.notebook1.Add (this.playsList);
+                       this.playsnotebook.Add (this.playsList);
                        // Notebook tab
                        this.playsList1 = new global::Gtk.Label ();
                        this.playsList1.Name = "playsList1";
                        this.playsList1.LabelProp = global::Mono.Unix.Catalog.GetString ("Plays");
-                       this.notebook1.SetTabLabel (this.playsList, this.playsList1);
+                       this.playsnotebook.SetTabLabel (this.playsList, this.playsList1);
                        this.playsList1.ShowAll ();
-                       // Container child notebook1.Gtk.Notebook+NotebookChild
+                       // Container child playsnotebook.Gtk.Notebook+NotebookChild
                        this.localPlayersList = new global::LongoMatch.Gui.Component.PlayersListTreeWidget ();
                        this.localPlayersList.Events = ((global::Gdk.EventMask)(256));
                        this.localPlayersList.Name = "localPlayersList";
-                       this.notebook1.Add (this.localPlayersList);
-                       global::Gtk.Notebook.NotebookChild w2 = 
((global::Gtk.Notebook.NotebookChild)(this.notebook1 [this.localPlayersList]));
+                       this.playsnotebook.Add (this.localPlayersList);
+                       global::Gtk.Notebook.NotebookChild w2 = 
((global::Gtk.Notebook.NotebookChild)(this.playsnotebook [this.localPlayersList]));
                        w2.Position = 1;
                        // Notebook tab
                        this.localPlaysList = new global::Gtk.Label ();
                        this.localPlaysList.Name = "localPlaysList";
-                       this.notebook1.SetTabLabel (this.localPlayersList, this.localPlaysList);
+                       this.playsnotebook.SetTabLabel (this.localPlayersList, this.localPlaysList);
                        this.localPlaysList.ShowAll ();
-                       // Container child notebook1.Gtk.Notebook+NotebookChild
+                       // Container child playsnotebook.Gtk.Notebook+NotebookChild
                        this.visitorPlayersList = new global::LongoMatch.Gui.Component.PlayersListTreeWidget 
();
                        this.visitorPlayersList.Events = ((global::Gdk.EventMask)(256));
                        this.visitorPlayersList.Name = "visitorPlayersList";
-                       this.notebook1.Add (this.visitorPlayersList);
-                       global::Gtk.Notebook.NotebookChild w3 = 
((global::Gtk.Notebook.NotebookChild)(this.notebook1 [this.visitorPlayersList]));
+                       this.playsnotebook.Add (this.visitorPlayersList);
+                       global::Gtk.Notebook.NotebookChild w3 = 
((global::Gtk.Notebook.NotebookChild)(this.playsnotebook [this.visitorPlayersList]));
                        w3.Position = 2;
                        // Notebook tab
                        this.visitorPlaysList = new global::Gtk.Label ();
                        this.visitorPlaysList.Name = "visitorPlaysList";
-                       this.notebook1.SetTabLabel (this.visitorPlayersList, this.visitorPlaysList);
+                       this.playsnotebook.SetTabLabel (this.visitorPlayersList, this.visitorPlaysList);
                        this.visitorPlaysList.ShowAll ();
-                       this.notebook2.Add (this.notebook1);
+                       this.notebook.Add (this.playsnotebook);
                        // Notebook tab
                        this.label1 = new global::Gtk.Label ();
                        this.label1.Name = "label1";
                        this.label1.LabelProp = global::Mono.Unix.Catalog.GetString ("  Plays Selection   ");
                        this.label1.Justify = ((global::Gtk.Justification)(2));
                        this.label1.Angle = 90;
-                       this.notebook2.SetTabLabel (this.notebook1, this.label1);
+                       this.notebook.SetTabLabel (this.playsnotebook, this.label1);
                        this.label1.ShowAll ();
-                       // Container child notebook2.Gtk.Notebook+NotebookChild
+                       // Container child notebook.Gtk.Notebook+NotebookChild
                        this.playlistwidget = new global::LongoMatch.Gui.Component.PlayListWidget ();
                        this.playlistwidget.WidthRequest = 100;
                        this.playlistwidget.Events = ((global::Gdk.EventMask)(256));
                        this.playlistwidget.Name = "playlistwidget";
-                       this.notebook2.Add (this.playlistwidget);
-                       global::Gtk.Notebook.NotebookChild w5 = 
((global::Gtk.Notebook.NotebookChild)(this.notebook2 [this.playlistwidget]));
+                       this.notebook.Add (this.playlistwidget);
+                       global::Gtk.Notebook.NotebookChild w5 = 
((global::Gtk.Notebook.NotebookChild)(this.notebook [this.playlistwidget]));
                        w5.Position = 1;
                        // Notebook tab
                        this.label3 = new global::Gtk.Label ();
                        this.label3.Name = "label3";
                        this.label3.LabelProp = global::Mono.Unix.Catalog.GetString ("Playlists");
                        this.label3.Angle = 90;
-                       this.notebook2.SetTabLabel (this.playlistwidget, this.label3);
+                       this.notebook.SetTabLabel (this.playlistwidget, this.label3);
                        this.label3.ShowAll ();
-                       // Container child notebook2.Gtk.Notebook+NotebookChild
-                       this.vbox3 = new global::Gtk.VBox ();
-                       this.vbox3.Name = "vbox3";
-                       this.vbox3.Spacing = 6;
-                       // Container child vbox3.Gtk.Box+BoxChild
+                       // Container child notebook.Gtk.Notebook+NotebookChild
+                       this.filtersvbox = new global::Gtk.VBox ();
+                       this.filtersvbox.Name = "filtersvbox";
+                       this.filtersvbox.Spacing = 6;
+                       // Container child filtersvbox.Gtk.Box+BoxChild
                        this.filtersnotebook = new global::Gtk.Notebook ();
                        this.filtersnotebook.CanFocus = true;
                        this.filtersnotebook.Name = "filtersnotebook";
                        this.filtersnotebook.CurrentPage = 0;
                        this.filtersnotebook.TabPos = ((global::Gtk.PositionType)(3));
-                       this.vbox3.Add (this.filtersnotebook);
-                       global::Gtk.Box.BoxChild w6 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.filtersnotebook]));
+                       this.filtersvbox.Add (this.filtersnotebook);
+                       global::Gtk.Box.BoxChild w6 = ((global::Gtk.Box.BoxChild)(this.filtersvbox 
[this.filtersnotebook]));
                        w6.Position = 0;
-                       // Container child vbox3.Gtk.Box+BoxChild
+                       // Container child filtersvbox.Gtk.Box+BoxChild
                        this.catfiltersbutton = new global::Gtk.ToggleButton ();
                        this.catfiltersbutton.CanFocus = true;
                        this.catfiltersbutton.Name = "catfiltersbutton";
@@ -136,12 +132,12 @@ namespace LongoMatch.Gui.Component
                        w8.Add (w11);
                        w7.Add (w8);
                        this.catfiltersbutton.Add (w7);
-                       this.vbox3.Add (this.catfiltersbutton);
-                       global::Gtk.Box.BoxChild w15 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.catfiltersbutton]));
+                       this.filtersvbox.Add (this.catfiltersbutton);
+                       global::Gtk.Box.BoxChild w15 = ((global::Gtk.Box.BoxChild)(this.filtersvbox 
[this.catfiltersbutton]));
                        w15.Position = 1;
                        w15.Expand = false;
                        w15.Fill = false;
-                       // Container child vbox3.Gtk.Box+BoxChild
+                       // Container child filtersvbox.Gtk.Box+BoxChild
                        this.playersfiltersbutton = new global::Gtk.ToggleButton ();
                        this.playersfiltersbutton.CanFocus = true;
                        this.playersfiltersbutton.Name = "playersfiltersbutton";
@@ -162,23 +158,22 @@ namespace LongoMatch.Gui.Component
                        w17.Add (w20);
                        w16.Add (w17);
                        this.playersfiltersbutton.Add (w16);
-                       this.vbox3.Add (this.playersfiltersbutton);
-                       global::Gtk.Box.BoxChild w24 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.playersfiltersbutton]));
+                       this.filtersvbox.Add (this.playersfiltersbutton);
+                       global::Gtk.Box.BoxChild w24 = ((global::Gtk.Box.BoxChild)(this.filtersvbox 
[this.playersfiltersbutton]));
                        w24.Position = 2;
                        w24.Expand = false;
                        w24.Fill = false;
-                       this.notebook2.Add (this.vbox3);
-                       global::Gtk.Notebook.NotebookChild w25 = 
((global::Gtk.Notebook.NotebookChild)(this.notebook2 [this.vbox3]));
+                       this.notebook.Add (this.filtersvbox);
+                       global::Gtk.Notebook.NotebookChild w25 = 
((global::Gtk.Notebook.NotebookChild)(this.notebook [this.filtersvbox]));
                        w25.Position = 2;
                        // Notebook tab
                        this.label2 = new global::Gtk.Label ();
                        this.label2.Name = "label2";
                        this.label2.LabelProp = global::Mono.Unix.Catalog.GetString ("  Filters  ");
                        this.label2.Angle = 90;
-                       this.notebook2.SetTabLabel (this.vbox3, this.label2);
+                       this.notebook.SetTabLabel (this.filtersvbox, this.label2);
                        this.label2.ShowAll ();
-                       this.lightbackgroundeventbox.Add (this.notebook2);
-                       this.Add (this.lightbackgroundeventbox);
+                       this.Add (this.notebook);
                        if ((this.Child != null)) {
                                this.Child.ShowAll ();
                        }